@@ -171,8 +171,8 @@ gnunet_conversation_gtk_ego_copy_button_clicked_cb (GtkButton *button,
 {
   struct GNUNET_IDENTITY_Ego *ego;
   const gchar *label;
-  const struct GNUNET_CRYPTO_EcdsaPrivateKey *priv;
-  struct GNUNET_CRYPTO_EcdsaPublicKey pub;
+  const struct GNUNET_IDENTITY_PrivateKey *priv;
+  struct GNUNET_IDENTITY_PublicKey pub;
   const char *zkey;
   char *uri;
   GtkClipboard *cb;
@@ -183,7 +183,7 @@ gnunet_conversation_gtk_ego_copy_button_clicked_cb (GtkButton *button,
   ego = GCG_EGOS_get_selected_ego ();
   GNUNET_break (NULL != ego);
   priv = GNUNET_IDENTITY_ego_get_private_key (ego);
-  GNUNET_CRYPTO_ecdsa_key_get_public (priv, &pub);
+  GNUNET_IDENTITY_ego_get_public_key (priv, &pub);
   zkey = GNUNET_GNSRECORD_pkey_to_zkey (&pub);
   GNUNET_asprintf (&uri, "gnunet://gns/%s.%s/", label, zkey);
   cb = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
