@@ -596,7 +596,7 @@ monitor_zone_sync (void *cls)
  */
 static void
 monitor_zone_records (void *cls,
-                      const struct GNUNET_CRYPTO_EcdsaPrivateKey *zone,
+                      const struct GNUNET_IDENTITY_PrivateKey *zone,
                       const char *label,
                       unsigned int rd_count,
                       const struct GNUNET_GNSRECORD_Data *rd)
@@ -663,7 +663,7 @@ handle_sks_zone_identity (void *cls,
         "No default ego specified for `fs-sks` service, will not enable namespace search.\n"));
     return;
   }
-  main_context.sks_zone = GNUNET_new (struct GNUNET_CRYPTO_EcdsaPrivateKey);
+  main_context.sks_zone = GNUNET_new (struct GNUNET_IDENTITY_PrivateKey);
   *main_context.sks_zone = *GNUNET_IDENTITY_ego_get_private_key (ego);
   gtk_widget_show (GTK_WIDGET (GNUNET_FS_GTK_get_main_window_object (
                                  "main_window_search_namespace_label")));
