@@ -133,7 +133,7 @@ struct PseuLookupContext
   /**
    * Public key of the namespace we are trying to save.
    */
-  struct GNUNET_CRYPTO_EcdsaPublicKey pkey;
+  struct GNUNET_IDENTITY_PublicKey pkey;
 
   /**
    * Nickname we're saving under.
@@ -253,7 +253,7 @@ struct GNUNET_GTK_MainWindowContext
   /**
    * Our zone for SKS operations.  Can be NULL.
    */
-  struct GNUNET_CRYPTO_EcdsaPrivateKey *sks_zone;
+  struct GNUNET_IDENTITY_PrivateKey *sks_zone;
 };
 
 
