@@ -294,7 +294,7 @@ GNUNET_FS_GTK_handle_uri (const struct GNUNET_FS_Uri *uri,
   GtkEntry *query_entry;
   GtkComboBox *ns_cb;
   GtkEntry *ns_entry;
-  struct GNUNET_CRYPTO_EcdsaPublicKey want;
+  struct GNUNET_IDENTITY_PublicKey want;
 
 
   if (GNUNET_FS_uri_test_chk (uri) || GNUNET_FS_uri_test_loc (uri))
