@@ -133,11 +133,6 @@ handle_gns_result (void *cls,
   {
     if (GNUNET_GNSRECORD_TYPE_PKEY != rd[i].record_type)
       continue;
-    if (sizeof (struct GNUNET_CRYPTO_EcdsaPublicKey) != rd[i].data_size)
-    {
-      GNUNET_break_op (0);
-      continue;
-    }
     uri = GNUNET_FS_uri_sks_create (rd[i].data, sl->keywords);
     search_for_uri (uri, sl->anonymity_level);
     abort_search_lookup (sl);
@@ -162,7 +157,7 @@ start_search (struct GNUNET_GTK_MainWindowContext *main_ctx)
   gchar *mime_keyword;
   const char *nsid;
   struct GNUNET_FS_Uri *uri;
-  struct GNUNET_CRYPTO_EcdsaPublicKey pub_sks_zone;
+  struct GNUNET_IDENTITY_PublicKey pub_sks_zone;
   struct SearchLookup *sl;
   char *emsg;
 
@@ -235,7 +230,7 @@ start_search (struct GNUNET_GTK_MainWindowContext *main_ctx)
     sl->anonymity_level = anonymity_level;
     sl->timeout_task =
       GNUNET_SCHEDULER_add_delayed (LOOKUP_TIMEOUT, &timeout_search_lookup, sl);
-    GNUNET_CRYPTO_ecdsa_key_get_public (main_ctx->sks_zone, &pub_sks_zone);
+    GNUNET_IDENTITY_ego_get_public_key (main_ctx->sks_zone, &pub_sks_zone);
     sl->gns = GNUNET_GNS_lookup (main_ctx->gns,
                                  nsid,
                                  &pub_sks_zone,
@@ -413,7 +408,7 @@ save_pseudonym_with_nick (struct PseuLookupContext *lctx, const char *nick)
   /* show the window */
   gtk_window_present (GTK_WINDOW (lctx->progress_dialog));
   memset (&rd, 0, sizeof (rd));
-  rd.data_size = sizeof (struct GNUNET_CRYPTO_EcdsaPublicKey);
+  rd.data_size = GNUNET_IDENTITY_key_get_length (&lctx->pkey);
   rd.data = &lctx->pkey;
   rd.flags = GNUNET_GNSRECORD_RF_PRIVATE;
   rd.expiration_time = GNUNET_TIME_UNIT_FOREVER_ABS.abs_value_us;
@@ -652,7 +647,7 @@ GNUNET_FS_GTK_save_button_clicked_cb (GtkButton *button, gpointer user_data)
   struct GNUNET_GTK_MainWindowContext *main_ctx = user_data;
   GtkComboBox *widget;
   const gchar *text;
-  struct GNUNET_CRYPTO_EcdsaPublicKey pkey;
+  struct GNUNET_IDENTITY_PublicKey pkey;
   int ret;
   struct PseuLookupContext *lctx;
   guint anonymity_level;
@@ -728,7 +723,7 @@ main_window_search_namespace_combobox_changed_cb (GtkComboBox *widget,
 {
   GtkButton *button;
   const gchar *text;
-  struct GNUNET_CRYPTO_EcdsaPublicKey pkey;
+  struct GNUNET_IDENTITY_PublicKey pkey;
   int ret;
 
   text = gtk_entry_get_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (widget))));
