@@ -2196,7 +2196,7 @@ insert_advertisement (void *cls,
                       void **client_info)
 {
   struct MainPublishingDialogContext *ctx = cls;
-  struct GNUNET_CRYPTO_EcdsaPublicKey pub;
+  struct GNUNET_IDENTITY_PublicKey pub;
   struct GNUNET_FS_Uri *sks_uri;
   char *sks_uri_string;
 
