@@ -958,7 +958,7 @@ GNUNET_GTK_main_loop_start (const char *binary_name,
     GNUNET_CONFIGURATION_destroy (ml.cfg);
     ml.cfg = NULL;
   }
-  GNUNET_free_non_null (ml.cfgfile);
+  GNUNET_free (ml.cfgfile);
   return ret;
 }
 
