@@ -467,9 +467,9 @@ free_peer_address (struct PeerInfo *info, struct PeerAddress *pa)
     pa->tos = NULL;
   }
   gtk_tree_row_reference_free (pa->rr);
-  GNUNET_free_non_null (pa->plugin);
-  GNUNET_free_non_null (pa->address_as_string);
-  GNUNET_free_non_null (pa->country_name);
+  GNUNET_free (pa->plugin);
+  GNUNET_free (pa->address_as_string);
+  GNUNET_free (pa->country_name);
   GNUNET_free (pa);
 }
 
